%define name    puppet
%define version 2.7.22
%define release %mkrel 1

%define ppconfdir conf/redhat

Name:           %{name}  
Version:        %{version}
Release:        %{release}
Summary:        System Automation and Configuration Management Software
License:        Apache Software License 
Group:          Monitoring
URL:            http://www.puppetlabs.com/
Source0:        http://puppetlabs.com/downloads/puppet/%{name}-%{version}.tar.gz
Source100:      puppet.service
Source101:      puppetmaster.service
Source102:      %{name}-tmpfiles.conf
BuildArch:      noarch
BuildRequires:	ruby facter
Requires:       facter
Suggests:       vim-puppet
Suggests:       emacs-puppet
Requires(post): systemd >= %{systemd_required_version}
Requires(pre):  rpm-helper
Requires(post): rpm-helper
Requires(preun):rpm-helper

%description
Puppet lets you centrally manage every important aspect of your system using a 
cross-platform specification language that manages all the separate elements 
normally aggregated in different files, like users, cron jobs, and hosts, 
along with obviously discrete elements like packages, services, and files.

This package provide the puppet client daemon.

%package server
Group:          Monitoring 
Summary:        Server for the puppet system management tool
Requires:       %{name} = %{version}
Requires(post): rpm-helper
Requires(preun):rpm-helper
                
%description server
Provides the central puppet server daemon (puppetmaster) which provides
manifests to clients.
The server can also function as a certificate authority and file server.

%package -n vim-puppet
Group:          Editors
Summary:        Syntax highlighting for puppet manifests in vim
                
%description -n vim-puppet
The vim-puppet package provides filetype detection and syntax highlighting for
puppet manifests (files ending with ".pp").

%package -n emacs-puppet
Group:          Editors
Summary:        Syntax highlighting for puppet manifests in emacs
                
%description -n emacs-puppet
The emacs-puppet package provides filetype detection and syntax highlighting for
puppet manifests (files ending with ".pp").

%prep
%setup -q

%build
# Use /usr/bin/ruby directly instead of /usr/bin/env ruby in
#+ executables. Otherwise, initscripts break since pidof can't
#+ find the right process
for f in bin/* ; do 
  sed -i -e '1c#!/usr/bin/ruby' $f
done

%install
%{__rm} -rf %{buildroot}

ruby install.rb --destdir=%{buildroot} --quick --no-rdoc

%{__install} -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests
%{__install} -d -m 0755 %{buildroot}%{_defaultdocdir}/%{name}
%{__install} -d -m 0755 %{buildroot}%{_localstatedir}/lib/%{name}
%{__install} -D -p -m 0644 %{SOURCE102} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -d -m 0755 %{buildroot}%{_logdir}/%{name}

#%{__find} %{buildroot}%{ruby_sitelibdir}/%{name} -type f -perm +ugo+x -print0 | xargs -0 -r %{__chmod} a-x
#
%{__install} -Dp -m 0644 %{ppconfdir}/client.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/puppetd
%{__install} -Dp -m 0644 %{ppconfdir}/server.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/puppetmasterd
%{__install} -Dp -m 0644 %{ppconfdir}/fileserver.conf %{buildroot}%{_sysconfdir}/%{name}/fileserver.conf
%{__install} -Dp -m 0644 %{ppconfdir}/puppet.conf %{buildroot}%{_sysconfdir}/%{name}/puppet.conf
# We need something for these ghosted files, otherwise rpmbuild
# will complain loudly. They won't be included in the binary packages
touch %{buildroot}%{_sysconfdir}/%{name}/puppetmasterd.conf
touch %{buildroot}%{_sysconfdir}/%{name}/puppetca.conf
touch %{buildroot}%{_sysconfdir}/%{name}/puppetd.conf

# logrotate
install -d  %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/puppet <<EOF
/var/log/puppet/*log {
    missingok
    notifempty
    create 0644 puppet puppet
    sharedscripts
    postrotate
        /bin/systemctl reload puppet.service > /dev/null 2>/dev/null || true
        /bin/systemctl reload puppetmaster.service > /dev/null 2>/dev/null || true
    endscript
}
EOF

# systemd
%{__install} -d -m 0755 %{buildroot}%{_unitdir}
%{__install} -m 755 %{SOURCE100} %{buildroot}%{_unitdir}/puppet.service
%{__install} -m 755 %{SOURCE101} %{buildroot}%{_unitdir}/puppetmaster.service

## install vim syntax file
%{__install} -d -m 755 %{buildroot}%{_datadir}/vim/syntax
%{__install} -d -m 755 %{buildroot}%{_datadir}/vim/ftdetect

%{__install} -m 644 ext/vim/syntax/puppet.vim %{buildroot}%{_datadir}/vim/syntax
%{__install} -m 644 ext/vim/ftdetect/puppet.vim %{buildroot}%{_datadir}/vim/ftdetect

## install emacs syntax file
%{__install} -d -m 0755 %{buildroot}%{_sysconfdir}/emacs/site-start.d
%{__install} -d -m 0755 %{buildroot}%{_datadir}/emacs/site-lisp
%{__install} -m 0644 ext/emacs/puppet-mode-init.el %{buildroot}%{_sysconfdir}/emacs/site-start.d
%{__install} -m 0644 ext/emacs/puppet-mode.el %{buildroot}%{_datadir}/emacs/site-lisp

## Install logcheck files
%{__install} -d -m 0755 %{buildroot}%{_sysconfdir}/logcheck/ignore.d.{server,workstation}
%{__install} -m 0644 ext/logcheck/puppet %{buildroot}%{_sysconfdir}/logcheck/ignore.d.server/
%{__install} -m 0644 ext/logcheck/puppet %{buildroot}%{_sysconfdir}/logcheck/ignore.d.workstation/

%pre
%_pre_useradd puppet %{_localstatedir}/lib/%{name} /sbin/nologin 

%post
%_tmpfilescreate %{name}
%_post_service puppet

%preun
%_preun_service puppet 

%post server
%_post_service puppetmaster

%preun server
%_preun_service puppetmaster 

%files
%doc CHANGELOG LICENSE examples
%dir %{_sysconfdir}/puppet
%{_bindir}/puppet
%{_bindir}/ralsh
%{_bindir}/pi
%{_bindir}/filebucket
%{_bindir}/puppetdoc
%{_sbindir}/puppetd
%{ruby_sitelibdir}/puppet.rb
%{ruby_sitelibdir}/%{name}
%{ruby_sitelibdir}/semver.rb
%{_unitdir}/puppet.service
%{_tmpfilesdir}/%{name}.conf

%{_mandir}/man8/puppet.*
%{_mandir}/man8/ralsh.*
%{_mandir}/man8/pi.*
%{_mandir}/man8/filebucket.*
%{_mandir}/man8/puppetdoc.*
%{_mandir}/man8/puppetd.*
%{_mandir}/man5/puppet.conf.*
%{_mandir}/man8/puppet-*
 
%config(noreplace) %{_sysconfdir}/sysconfig/puppetd
%config(noreplace) %{_sysconfdir}/%{name}/puppet.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/puppet
%ghost %config(noreplace,missingok) %{_sysconfdir}/%{name}/puppetd.conf

%{_sysconfdir}/logcheck/ignore.d.workstation/%{name}
%{_sysconfdir}/logcheck/ignore.d.server/

# These need to be owned by puppet so the server can
# write to them
%attr(-, %{name}, %{name}) %{_logdir}/%{name}
%attr(-, %{name}, %{name}) %{_localstatedir}/lib/%{name}

%files server
%{_sbindir}/puppetmasterd
%{_sbindir}/puppetca
%{_sbindir}/puppetrun
%{_sbindir}/puppetqd
%{_unitdir}/puppetmaster.service
%config(noreplace) %{_sysconfdir}/%{name}/fileserver.conf
%config(noreplace) %{_sysconfdir}/%{name}/auth.conf
%dir %{_sysconfdir}/puppet/manifests
%config(noreplace) %{_sysconfdir}/sysconfig/puppetmasterd
%ghost %config(noreplace,missingok) %{_sysconfdir}/%{name}/puppetca.conf
%ghost %config(noreplace,missingok) %{_sysconfdir}/%{name}/puppetmasterd.conf

%{_mandir}/man8/puppetca.*
%{_mandir}/man8/puppetrun.*
%{_mandir}/man8/puppetqd.*
%{_mandir}/man8/puppetmasterd.*

%files -n vim-puppet
%{_datadir}/vim/syntax/puppet.vim
%{_datadir}/vim/ftdetect/puppet.vim

%files -n emacs-puppet
%{_sysconfdir}/emacs/site-start.d/puppet-mode-init.el
%{_datadir}/emacs/site-lisp/puppet-mode.el


%changelog
* Wed Jun 19 2013 boklm <boklm> 2.7.22-1.mga3
+ Revision: 445091
- Update to version 2.7.22 to fix CVE-2013-3567 (Unauthenticated Remote
  Code Execution Vulnerability)

* Sat May 11 2013 guillomovitch <guillomovitch> 2.7.21-2.mga3
+ Revision: 413007
- use systemctl in logrotate, instead of sysinit script

* Fri Apr 05 2013 guillomovitch <guillomovitch> 2.7.21-1.mga3
+ Revision: 408245
- new version

  + neoclust <neoclust>
    - New sec fixes version

  + colin <colin>
    - Add systemd requires and general post/pre fixes (mga#9302)

* Sun Jan 13 2013 umeabot <umeabot> 2.7.20-3.mga3
+ Revision: 378317
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 16 2012 colin <colin> 2.7.20-2.mga3
+ Revision: 331700
- Switch to tmpfiles for /run dirs

* Wed Dec 12 2012 nanardon <nanardon> 2.7.20-1.mga3
+ Revision: 329851
- 2.7.20

* Mon Aug 13 2012 guillomovitch <guillomovitch> 2.7.18-1.mga3
+ Revision: 281054
- new version

* Fri Jul 06 2012 guillomovitch <guillomovitch> 2.7.17-1.mga3
+ Revision: 268416
- new version

* Mon Jun 11 2012 guillomovitch <guillomovitch> 2.7.14-1.mga3
+ Revision: 259755
- split emacs and vim extensions into distinct subpackages
- new version
- systemd support
- drop sysinit support

* Sat Feb 25 2012 misc <misc> 2.7.11-1.mga2
+ Revision: 214730
- new version 2.7.11 ( security and maintainance fix )

* Fri Feb 17 2012 misc <misc> 2.7.10-1.mga2
+ Revision: 210067
- upgrade to 2.7.10

* Mon Oct 24 2011 misc <misc> 2.7.6-1.mga2
+ Revision: 157871
- new version ( security issue )

* Mon Oct 03 2011 misc <misc> 2.7.5-1.mga2
+ Revision: 151298
- new version
- reupload the new tarball
- remove clean and defattr
- new version

* Thu Jun 23 2011 misc <misc> 2.7.1-1.mga2
+ Revision: 112565
- new version of puppet

* Wed May 04 2011 misc <misc> 2.6.8-1.mga1
+ Revision: 94686
- upgrade to 2.6.8, maintainance release

* Tue Apr 05 2011 misc <misc> 2.6.7-1.mga1
+ Revision: 80806
- update to latest version

* Mon Jan 24 2011 misc <misc> 2.6.4-1.mga1
+ Revision: 35788
- clean version specific and extranous requires
- imported package puppet

